@@ -3,6 +3,7 @@ __license__ = "Apache-2.0"
 
 import argparse
 import os
+from typing import List
 
 
 def api_to_dict():
@@ -35,7 +36,8 @@ def api_to_dict():
 
 def _export_parser_args(parser_fn, type_as_str: bool = False):
     from jina.enums import BetterEnum
-    from argparse import _StoreAction, _StoreTrueAction
+    from argparse import _StoreAction, _StoreTrueAction, _HelpAction, _SubParsersAction
+    from jina.parsers.helper import KVAppendAction
 
     port_attr = ('help', 'choices', 'default', 'required', 'option_strings', 'dest')
     parser = parser_fn()
@@ -45,10 +47,12 @@ def _export_parser_args(parser_fn, type_as_str: bool = False):
         if a.default != b.default:
             random_dest.add(a.dest)
     for a in parser._actions:
-        if isinstance(a, (_StoreAction, _StoreTrueAction)) and a.help != argparse.SUPPRESS:
+        if isinstance(a, (_StoreAction, _StoreTrueAction, KVAppendAction)) and a.help != argparse.SUPPRESS:
             ddd = {p: getattr(a, p) for p in port_attr}
             if isinstance(a, _StoreTrueAction):
                 ddd['type'] = bool
+            elif isinstance(a, KVAppendAction):
+                ddd['type'] = dict
             else:
                 ddd['type'] = a.type
             if ddd['choices']:
@@ -57,16 +61,22 @@ def _export_parser_args(parser_fn, type_as_str: bool = False):
             if isinstance(ddd['default'], BetterEnum):
                 ddd['default'] = str(ddd['default'])
                 ddd['type'] = str
-            if a.dest in random_dest:
-                ddd['default_random'] = True
-                from jina.helper import random_identity, random_port
-                if isinstance(a.default, str):
-                    ddd['default_factory'] = random_identity.__name__
-                elif isinstance(a.default, int):
-                    ddd['default_factory'] = random_port.__name__
-            else:
-                ddd['default_random'] = False
-            if type_as_str:
-                ddd['type'] = ddd['type'].__name__
-            ddd['name'] = ddd.pop('dest')
-            yield ddd
+            if ddd['type'] == str and (a.nargs == '*' or a.nargs == '+'):
+                ddd['type'] = List[str]
+        else:
+            continue
+
+        if a.dest in random_dest:
+            ddd['default_random'] = True
+            from jina.helper import random_identity, random_port
+            if isinstance(a.default, str):
+                ddd['default_factory'] = random_identity.__name__
+            elif isinstance(a.default, int):
+                ddd['default_factory'] = random_port.__name__
+        else:
+            ddd['default_random'] = False
+
+        if type_as_str:
+            ddd['type'] = getattr(ddd['type'], '__name__', str(ddd['type']))
+        ddd['name'] = ddd.pop('dest')
+        yield ddd
