@@ -9,7 +9,7 @@ import time
 import urllib.parse
 import urllib.request
 import webbrowser
-from typing import Dict, Any, Optional, List
+from typing import Dict, Any, List
 
 from .checker import *
 from .helper import credentials_file
@@ -67,8 +67,12 @@ class HubIO:
             # low-level client
             self._raw_client = APIClient(base_url='unix://var/run/docker.sock')
 
-    def new(self) -> None:
-        """Create a new executor using cookiecutter template."""
+    def new(self, no_input: bool = False) -> None:
+        """
+        Create a new executor using cookiecutter template.
+        
+        :param no_input: Argument to avoid prompting dialogue (just to be used for testing)
+        """
         with ImportExtensions(required=True):
             from cookiecutter.main import cookiecutter
             import click  # part of cookiecutter
@@ -80,8 +84,8 @@ class HubIO:
             cookiecutter_template = 'https://github.com/jina-ai/cookiecutter-jina-hub.git'
 
         try:
-            cookiecutter(cookiecutter_template, overwrite_if_exists=self.args.overwrite,
-                         output_dir=self.args.output_dir)
+            cookiecutter(template=cookiecutter_template, overwrite_if_exists=self.args.overwrite,
+                         output_dir=self.args.output_dir, no_input=no_input)
         except click.exceptions.Abort:
             self.logger.info('nothing is created, bye!')
 
@@ -228,26 +232,9 @@ class HubIO:
         with ProgressBar(task_name=f'pushing {name}', batch_unit='') as t:
             for line in self._client.images.push(name, stream=True, decode=True):
                 t.update(1)
-                if 'error' in line and 'authentication required' in line['error']:
-                    raise DockerLoginFailed('user not logged in to docker.')
                 self.logger.debug(line)
         self.logger.success(f'🎉 {name} is now published!')
 
-        if False and readme_path:
-            # unfortunately Docker Hub Personal Access Tokens cannot be used as they are not supported by the API
-            _volumes = {os.path.dirname(os.path.abspath(readme_path)): {'bind': '/workspace'}}
-            _env = {
-                'DOCKERHUB_USERNAME': self.args.username,
-                'DOCKERHUB_PASSWORD': self.args.password,
-                'DOCKERHUB_REPOSITORY': self.args.repository,
-                'README_FILEPATH': '/workspace/README.md',
-            }
-
-            self._client.containers.run('peterevans/dockerhub-description:2.1',
-                                        auto_remove=True,
-                                        volumes=_volumes,
-                                        environment=_env)
-
         share_link = f'https://api.jina.ai/hub/?jh={urllib.parse.quote_plus(name)}'
 
         try:
@@ -322,15 +309,18 @@ class HubIO:
 
             with TimeContext(f'building {colored(self.args.path, "green")}', self.logger) as tc:
                 try:
-                    self._check_completeness()
+                    _check_result = self._check_completeness()
                     self._freeze_jina_version()
 
+                    _dockerfile = os.path.basename(_check_result['Dockerfile'])
+                    _labels = {_label_prefix + k: str(v) for k, v in self.manifest.items()}
                     streamer = self._raw_client.build(
                         decode=True,
                         path=self.args.path,
                         tag=self.tag,
                         pull=self.args.pull,
-                        dockerfile=self.dockerfile_path_revised,
+                        dockerfile=_dockerfile,
+                        labels=_labels,
                         rm=True
                     )
 
@@ -357,7 +347,8 @@ class HubIO:
                 image, log = self._client.images.build(path=self.args.path,
                                                        tag=self.tag,
                                                        pull=self.args.pull,
-                                                       dockerfile=self.dockerfile_path_revised,
+                                                       dockerfile=_dockerfile,
+                                                       labels=_labels,
                                                        rm=True)
 
                 # success
@@ -385,7 +376,8 @@ class HubIO:
                                                                         self.args.test_level,
                                                                         self.config_yaml_path,
                                                                         self.args.timeout_ready,
-                                                                        self.args.daemon)
+                                                                        self.args.daemon,
+                                                                        self.logger)
                         if any(test_level in failed_test_levels for test_level in
                                [BuildTestLevel.POD_DOCKER, BuildTestLevel.FLOW]):
                             is_build_success = False
@@ -467,30 +459,38 @@ class HubIO:
                     test_level: 'BuildTestLevel',
                     config_yaml_path: str,
                     timeout_ready: int,
-                    daemon_arg: bool):
+                    daemon_arg: bool,
+                    logger: 'JinaLogger'):
         p_names = []
         failed_levels = []
-
+        logger.info(f'run tests using test level {test_level}')
         # test uses at executor level
         if test_level >= BuildTestLevel.EXECUTOR:
+            logger.info(f'test to initialize an executor from yaml configuration: {config_yaml_path}')
             try:
                 with BaseExecutor.load_config(config_yaml_path):
                     pass
+                logger.info(f'successfully tested to initialize an executor')
             except:
+                logger.error(f'failed to initialize an executor')
                 failed_levels.append(BuildTestLevel.EXECUTOR)
 
         # test uses at Pod level (no docker)
         if test_level >= BuildTestLevel.POD_NONDOCKER:
+            logger.info(f'test to initialize a pod from yaml configuration: {config_yaml_path}')
             try:
                 with Pod(set_pod_parser().parse_args(
                         ['--uses', config_yaml_path, '--timeout-ready', str(timeout_ready)])):
                     pass
+                logger.info(f'successfully tested to initialize a pod from yaml configuration')
             except:
+                logger.error(f'failed to initialize a pod')
                 failed_levels.append(BuildTestLevel.POD_NONDOCKER)
 
         # test uses at Pod level (with docker)
         if test_level >= BuildTestLevel.POD_DOCKER:
             p_name = random_name()
+            logger.info(f'test to initialize a pod via docker image {image.tags[0]} named {p_name}')
             try:
                 with Pod(set_pod_parser().parse_args(
                         ['--uses', f'docker://{image.tags[0]}', '--name', p_name, '--timeout-ready',
@@ -498,20 +498,25 @@ class HubIO:
                         ['--daemon'] if daemon_arg else [])):
                     pass
                 p_names.append(p_name)
+                logger.info(f'successfully tested to initialize a pod via docker')
             except:
+                logger.error(f'failed to initialize a pod via docker image')
                 failed_levels.append(BuildTestLevel.POD_DOCKER)
 
         # test uses at Flow level
         if test_level >= BuildTestLevel.FLOW:
             p_name = random_name()
+            logger.info(f'test to build a flow from docker image {image.tags[0]} named {p_name} '
+                        f'with daemon={daemon_arg} and timeout_ready={timeout_ready}')
             try:
-                with Flow().add(name=random_name(), uses=f'docker://{image.tags[0]}', daemon=daemon_arg,
+                with Flow().add(name=p_name, uses=f'docker://{image.tags[0]}', daemon=daemon_arg,
                                 timeout_ready=timeout_ready):
                     pass
                 p_names.append(p_name)
+                logger.info('successfully tested to build a flow from docker image')
             except:
+                logger.error(f'failed to build a flow from docker image')
                 failed_levels.append(BuildTestLevel.FLOW)
-
         return p_names, failed_levels
 
     def dry_run(self) -> Dict:
@@ -593,7 +598,6 @@ class HubIO:
 
         self.manifest = self._read_manifest(manifest_path)
         self.manifest['jina_version'] = jina_version
-        self.dockerfile_path_revised = self._get_revised_dockerfile(dockerfile_path, self.manifest)
         self.executor_name = safe_url_name(
             f'{self.args.repository}/' + f'{self.manifest["type"]}.{self.manifest["kind"]}.{self.manifest["name"]}')
         self.tag = self.executor_name + f':{self.manifest["version"]}-{jina_version}'
@@ -646,25 +650,6 @@ class HubIO:
         for k, v in manifest.items():
             self.logger.debug(f'{k}: {v}')
 
-    def _get_revised_dockerfile(self, dockerfile_path: str, manifest: Dict) -> str:
-        # modify dockerfile
-        revised_dockerfile = []
-        with open(dockerfile_path) as fp:
-            for l in fp:
-                revised_dockerfile.append(l)
-                if l.startswith('FROM'):
-                    revised_dockerfile.append('LABEL ')
-                    revised_dockerfile.append(
-                        ' \\      \n'.join(f'{_label_prefix}{k}="{v}"' for k, v in manifest.items()))
-
-        f = tempfile.NamedTemporaryFile('w', delete=False).name
-        with open(f, 'w', encoding='utf8') as fp:
-            fp.writelines(revised_dockerfile)
-
-        for k in revised_dockerfile:
-            self.logger.debug(k)
-        return f
-
     def _write_slack_message(self, *args):
         def _expand_fn(v):
             if isinstance(v, str):
