@@ -26,16 +26,16 @@ class CompoundExecutor(BaseExecutor):
               index_filename: vec.gz
             metas:
               name: vecidx_exec  # a customized name
-              workspace: $TEST_WORKDIR
+              workspace: ${{TEST_WORKDIR}}
           - !BinaryPbIndexer
             with:
               index_filename: chunk.gz
             metas:
               name: chunkidx_exec
-              workspace: $TEST_WORKDIR
+              workspace: ${{TEST_WORKDIR}}
         metas:
           name: chunk_compound_indexer
-          workspace: $TEST_WORKDIR
+          workspace: ${{TEST_WORKDIR}}
         requests:
           on:
             SearchRequest:
@@ -59,7 +59,7 @@ class CompoundExecutor(BaseExecutor):
           - !GifNameRawSplit
             metas:
               name: name_split  # a customized name
-              workspace: $TEST_WORKDIR
+              workspace: ${{TEST_WORKDIR}}
           - !GifPreprocessor
             with:
               every_k_frame: 2
@@ -68,7 +68,7 @@ class CompoundExecutor(BaseExecutor):
               name: gif2chunk_preprocessor  # a customized name
         metas:
           name: compound_crafter
-          workspace: $TEST_WORKDIR
+          workspace: ${{TEST_WORKDIR}}
           py_modules: gif2chunk.py
         requests:
           on:
@@ -93,7 +93,7 @@ class CompoundExecutor(BaseExecutor):
         c[0].add(obj)
 
     .. note::
-        All components ``workspace`` and ``pea_workspace`` are overrided by their :class:`CompoundExecutor` counterparts.
+        Component ``workspace`` and ``pea_id`` are overriden by their :class:`CompoundExecutor` counterparts.
 
     .. warning::
 
@@ -192,6 +192,10 @@ class CompoundExecutor(BaseExecutor):
                 - dummyB-e3acc910
                 - say
 
+        .. warning::
+
+            When setting inner `executors` in `components` the `workspace` configuration will not be used and will be overriden
+            by a workspace extracted considering the name of the `CompoundExecutor`, the name of each internal `Component` and the `pea_id`
         """
         super().__init__(*args, **kwargs)
         self._components = None  # type: List[AnyExecutor]
@@ -248,22 +252,42 @@ class CompoundExecutor(BaseExecutor):
         if not callable(comps):
             raise TypeError('components must be a callable function that returns '
                             'a List[BaseExecutor]')
-        if not getattr(self, 'init_from_yaml', False):
+
+        # Important to handle when loading a CompoundExecutor when `inner` executors have not been loaded from yaml
+        if not getattr(self, '_init_from_yaml', False):
             self._components = comps()
             if not isinstance(self._components, list):
                 raise TypeError(f'components expect a list of executors, receiving {type(self._components)!r}')
-            # self._set_comp_workspace()
+            self._set_comp_workspace()
             self._set_routes()
             self._resolve_routes()
         else:
             self.logger.debug('components is omitted from construction, as it is initialized from yaml config')
 
+    @staticmethod
+    def get_component_workspace_from_compound_workspace(compound_workspace: str, compound_name: str,
+                                                        pea_id: int) -> str:
+        """
+        Get the name of workspace.
+
+        :param compound_workspace: Workspace of the compound executor.
+        :param compound_name: Name of the compound executor.
+        :param pea_id: Id of the pea.
+        :return: The name of workspace.
+        """
+        import os
+        return BaseExecutor.get_shard_workspace(compound_workspace, compound_name, pea_id) if (
+                    isinstance(pea_id, int) and pea_id > 0) else \
+            os.path.join(compound_workspace, compound_name)
+
     def _set_comp_workspace(self) -> None:
-        # overrider the workspace setting for all components
+        # overrides the workspace setting for all components
         for c in self.components:
-            c.separated_workspace = self.separated_workspace
-            c.workspace = self.workspace
-            c.pea_workspace = self.current_workspace
+            if not c.workspace and self.workspace:
+                c_workspace = CompoundExecutor.get_component_workspace_from_compound_workspace(self.workspace,
+                                                                                               self.name, self.pea_id)
+                self.logger.warning(f'Setting workspace of {c.name} to {c_workspace}')
+                c.workspace = c_workspace
 
     def _resolve_routes(self) -> None:
         if self._routes:
@@ -334,19 +358,6 @@ class CompoundExecutor(BaseExecutor):
                 c.close()
         super().close()
 
-    @classmethod
-    def to_yaml(cls, representer, data):
-        tmp = super()._dump_instance_to_yaml(data)
-        tmp['components'] = data.components
-        return representer.represent_mapping('!' + cls.__name__, tmp)
-
-    @classmethod
-    def from_yaml(cls, constructor, node):
-        obj, data, from_dump = super()._get_instance_from_yaml(constructor, node)
-        if not from_dump and 'components' in data:
-            obj.components = lambda: data['components']
-        return obj
-
     def __contains__(self, item: str):
         if isinstance(item, str):
             for c in self.components:
