@@ -12,7 +12,7 @@ from collections import OrderedDict, defaultdict
 from contextlib import ExitStack
 from typing import Optional, Union, Tuple, List, Set, Dict, TextIO
 
-from .builder import build_required, _build_flow, _optimize_flow, _hanging_pods
+from .builder import build_required, _build_flow, _hanging_pods
 from .. import __default_host__
 from ..clients import Client, WebSocketClient
 from ..enums import FlowBuildLevel, PodRoleType, FlowInspectType
@@ -29,6 +29,7 @@ from ..peapods import BasePod
 
 
 class FlowType(type(ExitStack), type(JAMLCompatible)):
+    """Type of Flow, metaclass of :class:`BaseFlow`"""
     pass
 
 
@@ -36,35 +37,30 @@ _regex_port = r'(.*?):([0-9]{1,4}|[1-5][0-9]{4}|6[0-4][0-9]{3}|65[0-4][0-9]{2}|6
 
 
 class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
-    """An abstract flow object in Jina.
+    """An abstract Flow object in Jina.
 
     .. note::
+
         :class:`BaseFlow` does not provide `train`, `index`, `search` interfaces.
         Please use :class:`Flow` or :class:`AsyncFlow`.
+
+    Explanation on ``optimize_level``:
+
+    As an example, the following Flow will generate 6 Peas,
+
+    .. highlight:: python
+    .. code-block:: python
+
+        f = Flow.add(uses='forward', parallel=3)
+
+    :param kwargs: other keyword arguments that will be shared by all Pods in this Flow
+    :param args: Namespace args
+    :param env: environment variables shared by all Pods
     """
 
     _cls_client = Client  #: the type of the Client, can be changed to other class
 
     def __init__(self, args: Optional['argparse.Namespace'] = None, env: Optional[Dict] = None, **kwargs):
-        """Initialize a flow object
-
-        :param kwargs: other keyword arguments that will be shared by all pods in this flow
-
-
-        More explain on ``optimize_level``:
-
-        As an example, the following flow will generate 6 Peas,
-
-        .. highlight:: python
-        .. code-block:: python
-
-            f = Flow(optimize_level=FlowOptimizeLevel.NONE).add(uses='forward', parallel=3)
-
-        The optimized version, i.e. :code:`Flow(optimize_level=FlowOptimizeLevel.FULL)`
-        will generate 4 Peas, but it will force the :class:`GatewayPea` to take BIND role,
-        as the head and tail routers are removed.
-
-        """
         super().__init__()
         self._version = '1'  #: YAML version number, this will be later overridden if YAML config says the other way
         self._pod_nodes = OrderedDict()  # type: Dict[str, 'BasePod']
@@ -72,7 +68,7 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
         self._build_level = FlowBuildLevel.EMPTY
         self._last_changed_pod = ['gateway']  #: default first pod is gateway, will add when build()
         self._update_args(args, **kwargs)
-        self._env = env  #: environment vars shared by all pods in the flow
+        self._env = env
         if isinstance(self.args, argparse.Namespace):
             self.logger = JinaLogger(self.__class__.__name__, **vars(self.args))
         else:
@@ -91,6 +87,15 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     @property
     def yaml_spec(self):
+        """
+        get the YAML representation of the instance
+
+
+        .. # noqa: DAR401
+
+
+        .. # noqa: DAR201
+        """
         return JAML.dump(self)
 
     @staticmethod
@@ -117,16 +122,24 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     @property
     def last_pod(self):
+        """Last pod
+
+
+        .. # noqa: DAR401
+
+
+        .. # noqa: DAR201
+        """
         return self._last_changed_pod[-1]
 
     @last_pod.setter
     def last_pod(self, name: str):
         """
-        Set a pod as the last pod in the flow, useful when modifying the flow.
+        Set a Pod as the last Pod in the Flow, useful when modifying the Flow.
 
-        :param name: the name of the existing pod
-        :param copy_flow: when set to true, then always copy the current flow and do the modification on top of it then return, otherwise, do in-line modification
-        :return: a (new) flow object with modification
+
+        .. # noqa: DAR401
+        :param name: the name of the existing Pod
         """
         if name not in self._pod_nodes:
             raise FlowMissingPodError(f'{name} can not be found in this Flow')
@@ -159,11 +172,15 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
     def needs(self, needs: Union[Tuple[str], List[str]],
               name: str = 'joiner', *args, **kwargs) -> 'BaseFlow':
         """
-        Add a blocker to the flow, wait until all peas defined in **needs** completed.
+        Add a blocker to the Flow, wait until all peas defined in **needs** completed.
 
+
+        .. # noqa: DAR401
         :param needs: list of service names to wait
         :param name: the name of this joiner, by default is ``joiner``
-        :return: the modified flow
+        :param *args: *args for .add
+        :param **kwargs: **kwargs for .add
+        :return: the modified Flow
         """
         if len(needs) <= 1:
             raise FlowTopologyError('no need to wait for a single service, need len(needs) > 1')
@@ -171,10 +188,12 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     def needs_all(self, name: str = 'joiner', *args, **kwargs) -> 'BaseFlow':
         """
-        Collect all hanging Pod so far and add a blocker to the flow, wait until all handing peas completed.
+        Collect all hanging Pods so far and add a blocker to the Flow; wait until all handing peas completed.
         
-        :param name: the name of this joiner, by default is ``joiner``
-        :return: the modified flow
+        :param name: the name of this joiner (default is ``joiner``)
+        :param *args: *args for .add or .needs
+        :param **kwargs: **kwargs for .add or .needs
+        :return: the modified Flow
         """
         needs = _hanging_pods(self)
         if len(needs) == 1:
@@ -188,19 +207,21 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
             pod_role: 'PodRoleType' = PodRoleType.POD,
             **kwargs) -> 'BaseFlow':
         """
-        Add a pod to the current flow object and return the new modified flow object.
-        The attribute of the pod can be later changed with :py:meth:`set` or deleted with :py:meth:`remove`
+        Add a Pod to the current Flow object and return the new modified Flow object.
+        The attribute of the Pod can be later changed with :py:meth:`set` or deleted with :py:meth:`remove`
 
         Note there are shortcut versions of this method.
         Recommend to use :py:meth:`add_encoder`, :py:meth:`add_preprocessor`,
         :py:meth:`add_router`, :py:meth:`add_indexer` whenever possible.
 
-        :param needs: the name of the pod(s) that this pod receives data from.
+
+        .. # noqa: DAR401
+        :param needs: the name of the Pod(s) that this Pod receives data from.
                            One can also use 'pod.Gateway' to indicate the connection with the gateway.
         :param pod_role: the role of the Pod, used for visualization and route planning
-        :param copy_flow: when set to true, then always copy the current flow and do the modification on top of it then return, otherwise, do in-line modification
-        :param kwargs: other keyword-value arguments that the pod CLI supports
-        :return: a (new) flow object with modification
+        :param copy_flow: when set to true, then always copy the current Flow and do the modification on top of it then return, otherwise, do in-line modification
+        :param **kwargs: other keyword-value arguments that the Pod CLI supports
+        :return: a (new) Flow object with modification
         """
 
         op_flow = copy.deepcopy(self) if copy_flow else self
@@ -235,7 +256,7 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
                 kwargs['port_expose'] = m.group(2)
                 kwargs['host'] = m.group(1)
 
-        # update kwargs of this pod
+        # update kwargs of this Pod
         kwargs.update(dict(
             name=pod_name,
             pod_role=pod_role,
@@ -256,8 +277,8 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
     def inspect(self, name: str = 'inspect', *args, **kwargs) -> 'BaseFlow':
         """Add an inspection on the last changed Pod in the Flow
 
-        Internally, it adds two pods to the flow. But no worry, the overhead is minimized and you
-        can remove them by simply give `Flow(inspect=FlowInspectType.REMOVE)` before using the flow.
+        Internally, it adds two Pods to the Flow. But don't worry, the overhead is minimized and you
+        can remove them by simply using `Flow(inspect=FlowInspectType.REMOVE)` before using the Flow.
 
         .. highlight:: bash
         .. code-block:: bash
@@ -267,17 +288,20 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
                     -- PUB-SUB -- InspectPod (Hanging)
 
         In this way, :class:`InspectPod` looks like a simple ``_pass`` from outside and
-        does not introduce side-effect (e.g. changing the socket type) to the original flow.
+        does not introduce side-effects (e.g. changing the socket type) to the original Flow.
         The original incoming and outgoing socket types are preserved.
 
-        This function is very handy for introducing evaluator into the flow.
+        This function is very handy for introducing an Evaluator into the Flow.
 
         .. seealso::
 
             :meth:`gather_inspect`
 
+        :param name: name of the Pod
+        :param *args: *args for .add()
+        :param **kwargs: **kwargs for .add()
+        :return: the new instance of the Flow
         """
-
         _last_pod = self.last_pod
         op_flow = self.add(name=name, needs=_last_pod, pod_role=PodRoleType.INSPECT, *args, **kwargs)
 
@@ -287,14 +311,14 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
         op_flow = op_flow.add(name=f'_aux_{name}', needs=_last_pod,
                               pod_role=PodRoleType.INSPECT_AUX_PASS, *args, **kwargs)
 
-        # register any future connection to _last_pod by the auxiliary pod
+        # register any future connection to _last_pod by the auxiliary Pod
         op_flow._inspect_pods[_last_pod] = op_flow.last_pod
 
         return op_flow
 
     def gather_inspect(self, name: str = 'gather_inspect', uses='_merge_eval', include_last_pod: bool = True, *args,
                        **kwargs) -> 'BaseFlow':
-        """ Gather all inspect pods output into one pod. When the flow has no inspect pod then the flow itself
+        """ Gather all inspect Pods output into one Pod. When the Flow has no inspect Pod then the Flow itself
         is returned.
 
         .. note::
@@ -302,12 +326,12 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
             If ``--no-inspect`` is **not** given, then :meth:`gather_inspect` is auto called before :meth:`build`. So
             in general you don't need to manually call :meth:`gather_inspect`.
 
-        :param name: the name of the gather pod
+        :param name: the name of the gather Pod
         :param uses: the config of the executor, by default is ``_pass``
-        :param include_last_pod: if to include the last modified pod in the flow
-        :param args:
-        :param kwargs:
-        :return: the modified flow or the copy of it
+        :param include_last_pod: if to include the last modified Pod in the Flow
+        :param *args: *args for .add()
+        :param **kwargs: **kwargs for .add()
+        :return: the modified Flow or the copy of it
 
 
         .. seealso::
@@ -326,18 +350,18 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     def build(self, copy_flow: bool = False) -> 'BaseFlow':
         """
-        Build the current flow and make it ready to use
+        Build the current Flow and make it ready to use
 
         .. note::
 
-            No need to manually call it since 0.0.8. When using flow with the
+            No need to manually call it since 0.0.8. When using Flow with the
             context manager, or using :meth:`start`, :meth:`build` will be invoked.
 
-        :param copy_flow: when set to true, then always copy the current flow and do the modification on top of it then return, otherwise, do in-line modification
-        :return: the current flow (by default)
+        :param copy_flow: when set to true, then always copy the current Flow and do the modification on top of it then return, otherwise, do in-line modification
+        :return: the current Flow (by default)
 
         .. note::
-            ``copy_flow=True`` is recommended if you are building the same flow multiple times in a row. e.g.
+            ``copy_flow=True`` is recommended if you are building the same Flow multiple times in a row. e.g.
 
             .. highlight:: python
             .. code-block:: python
@@ -349,11 +373,12 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
                 with f.build(copy_flow=True) as fl:
                     fl.search()
 
+
+        .. # noqa: DAR401
         """
 
         op_flow = copy.deepcopy(self) if copy_flow else self
 
-        _pod_edges = set()
         if op_flow.args.inspect == FlowInspectType.COLLECT:
             op_flow.gather_inspect(copy_flow=False)
 
@@ -380,10 +405,8 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
                 if start not in op_flow._pod_nodes:
                     raise FlowMissingPodError(f'{start} is not in this flow, misspelled name?')
                 _outgoing_map[start].append(end)
-                _pod_edges.add((start, end))
 
         op_flow = _build_flow(op_flow, _outgoing_map)
-        op_flow = _optimize_flow(op_flow, _outgoing_map, _pod_edges)
         hanging_pods = _hanging_pods(op_flow)
         if hanging_pods:
             self.logger.warning(f'{hanging_pods} are hanging in this flow with no pod receiving from them, '
@@ -393,6 +416,11 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
         return op_flow
 
     def __call__(self, *args, **kwargs):
+        """Builds the Flow
+        :param *args: *args for build
+        :param **kwargs: **kwargs for build
+        :return: the built Flow
+        """
         return self.build(*args, **kwargs)
 
     def __enter__(self):
@@ -406,6 +434,7 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
             for k in self._env.keys():
                 os.unsetenv(k)
 
+        self._pod_nodes.pop('gateway')
         self._build_level = FlowBuildLevel.EMPTY
         self.logger.success(
             f'flow is closed and all resources are released, current build level is {self._build_level}')
@@ -418,19 +447,28 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
         Note that this method has a timeout of ``timeout_ready`` set in CLI,
         which is inherited all the way from :class:`jina.peapods.peas.BasePea`
+
+
+        .. # noqa: DAR401
+
+        :return: this instance
         """
 
         if self._build_level.value < FlowBuildLevel.GRAPH.value:
             self.build(copy_flow=False)
 
-        # set env only before the pod get started
+        # set env only before the Pod get started
         if self._env:
             for k, v in self._env.items():
                 os.environ[k] = str(v)
 
+        for k, v in self:
+            v.args.noblock_on_start = True
+            self.enter_context(v)
+
         for k, v in self:
             try:
-                self.enter_context(v)
+                v.wait_start_success()
             except Exception as ex:
                 self.logger.error(f'{k}:{v!r} can not be started due to {ex!r}, Flow is aborted')
                 self.close()
@@ -444,20 +482,27 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     @property
     def num_pods(self) -> int:
-        """Get the number of pods in this flow"""
+        """Get the number of Pods in this Flow
+
+
+        .. # noqa: DAR201"""
         return len(self._pod_nodes)
 
     @property
     def num_peas(self) -> int:
-        """Get the number of peas (parallel count) in this flow"""
+        """Get the number of peas (parallel count) in this Flow
+
+
+        .. # noqa: DAR201"""
         return sum(v.num_peas for v in self._pod_nodes.values())
 
-    def __eq__(self, other: 'BaseFlow'):
+    def __eq__(self, other: 'BaseFlow') -> bool:
         """
-        Comparing the topology of a flow with another flow.
+        Compare the topology of a Flow with another Flow.
         Identification is defined by whether two flows share the same set of edges.
 
-        :param other: the second flow object
+        :param other: the second Flow object
+        :return: result of equality check
         """
 
         if self._build_level.value < FlowBuildLevel.GRAPH.value:
@@ -552,7 +597,7 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
              build: bool = True,
              copy_flow: bool = False) -> 'BaseFlow':
         """
-        Visualize the flow up to the current point
+        Visualize the Flow up to the current point
         If a file name is provided it will create a jpg image with that name,
         otherwise it will display the URL for mermaid.
         If called within IPython notebook, it will be rendered inline,
@@ -569,13 +614,13 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
                     the suffix svg/jpg determines the file type of the output image
         :param vertical_layout: top-down or left-right layout
         :param inline_display: show image directly inside the Jupyter Notebook
-        :param build: build the flow first before plotting, gateway connection can be better showed
-        :param copy_flow: when set to true, then always copy the current flow and
+        :param build: build the Flow first before plotting, gateway connection can be better showed
+        :param copy_flow: when set to true, then always copy the current Flow and
                 do the modification on top of it then return, otherwise, do in-line modification
-        :return: the flow
+        :return: the Flow
         """
 
-        # deepcopy causes the below error while reusing a flow in Jupyter
+        # deepcopy causes the below error while reusing a Flow in Jupyter
         # 'Pickling an AuthenticationString object is disallowed for security reasons'
         op_flow = copy.deepcopy(self) if copy_flow else self
 
@@ -613,10 +658,12 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
         """Displays the object in IPython as a side effect"""
         self.plot(inline_display=True, build=(self._build_level != FlowBuildLevel.GRAPH))
 
-    def _mermaid_to_url(self, mermaid_str, img_type) -> str:
+    def _mermaid_to_url(self, mermaid_str: str, img_type: str) -> str:
         """
-        Rendering the current flow as a url points to a SVG, it needs internet connection
-        :param kwargs: keyword arguments of :py:meth:`to_mermaid`
+        Render the current Flow as URL points to a SVG. It needs internet connection
+
+        :param mermaid_str: the mermaid representation
+        :param img_type: image type (svg/jpg)
         :return: the url points to a SVG
         """
         if img_type == 'jpg':
@@ -651,25 +698,37 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
     @property
     @build_required(FlowBuildLevel.GRAPH)
     def port_expose(self) -> int:
-        """Return the exposed port of the gateway"""
+        """Return the exposed port of the gateway
+
+
+        .. # noqa: DAR201"""
         return self._pod_nodes['gateway'].port_expose
 
     @property
     @build_required(FlowBuildLevel.GRAPH)
     def host(self) -> str:
-        """Return the local address of the gateway """
+        """Return the local address of the gateway
+
+
+        .. # noqa: DAR201"""
         return self._pod_nodes['gateway'].host
 
     @property
     @build_required(FlowBuildLevel.GRAPH)
     def address_private(self) -> str:
-        """Return the private IP address of the gateway for connecting from other machine in the same network """
+        """Return the private IP address of the gateway for connecting from other machine in the same network
+
+
+        .. # noqa: DAR201"""
         return get_internal_ip()
 
     @property
     @build_required(FlowBuildLevel.GRAPH)
     def address_public(self) -> str:
-        """Return the public IP address of the gateway for connecting from other machine in the public network """
+        """Return the public IP address of the gateway for connecting from other machine in the public network
+
+
+        .. # noqa: DAR201"""
         return get_public_ip()
 
     def __iter__(self):
@@ -701,13 +760,19 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
         except KeyboardInterrupt:
             pass
 
-    def use_grpc_gateway(self):
-        """Change to use gRPC gateway for IO """
-        self._common_kwargs['rest_api'] = False
+    def use_grpc_gateway(self, port: int = None):
+        """Change to use gRPC gateway for IO
+        :param port: the port to change"""
+        self._common_kwargs['restful'] = False
+        if port:
+            self._common_kwargs['port_expose'] = port
 
-    def use_rest_gateway(self):
-        """Change to use REST gateway for IO """
-        self._common_kwargs['rest_api'] = True
+    def use_rest_gateway(self, port: int = None):
+        """Change to use REST gateway for IO
+        :param port: the port to change"""
+        self._common_kwargs['restful'] = True
+        if port:
+            self._common_kwargs['port_expose'] = port
 
     def __getitem__(self, item):
         if isinstance(item, str):
@@ -723,7 +788,10 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     @property
     def workspace_id(self) -> Dict[str, str]:
-        """Get all Pods' ``workspace_id`` values in a dict """
+        """Get all Pods' ``workspace_id`` values in a dict
+
+
+        .. # noqa: DAR201"""
         return {k: p.args.workspace_id for k, p in self if hasattr(p.args, 'workspace_id')}
 
     @workspace_id.setter
@@ -745,7 +813,11 @@ class BaseFlow(JAMLCompatible, ExitStack, metaclass=FlowType):
 
     @property
     def identity(self) -> Dict[str, str]:
-        """Get all Pods' ``identity`` values in a dict """
+        """Get all Pods' ``identity`` values in a dict
+
+
+        .. # noqa: DAR201
+        """
         return {k: p.args.identity for k, p in self}
 
     @identity.setter
