@@ -48,6 +48,13 @@ def _get_groundtruths(target, pseudo_match=True):
 
 
 def index_generator(num_docs: int, target: dict):
+    """
+    Generate the index data.
+
+    :param num_docs: Number of documents to be indexed.
+    :param target: Dictionary which stores the data paths
+    :yields: index data
+    """
     for internal_doc_id in range(num_docs):
         d = Document(content=target['index']['data'][internal_doc_id])
         d.tags['id'] = internal_doc_id
@@ -55,6 +62,14 @@ def index_generator(num_docs: int, target: dict):
 
 
 def query_generator(num_docs: int, target: dict, with_groundtruth: bool = True):
+    """
+    Generate the query data.
+
+    :param num_docs: Number of documents to be queried
+    :param target: Dictionary which stores the data paths
+    :param with_groundtruth: True if want to include labels into query data
+    :yields: query data
+    """
     gts = _get_groundtruths(target)
     for _ in range(num_docs):
         num_data = len(target['query-labels']['data'])
@@ -67,6 +82,11 @@ def query_generator(num_docs: int, target: dict, with_groundtruth: bool = True):
 
 
 def print_result(resp):
+    """
+    Callback function to receive results.
+
+    :param resp: returned response with data
+    """
     global evaluation_value
     global top_k
     for d in resp.search.docs:
@@ -85,17 +105,22 @@ def print_result(resp):
 
 
 def write_html(html_path):
+    """
+    Method to present results in browser.
+
+    :param html_path: path of the written html
+    """
     global num_docs_evaluated
     global evaluation_value
 
-    with open(resource_filename('jina', '/'.join(('resources', 'helloworld.html'))), 'r') as fp, \
+    with open(resource_filename('jina', '/'.join(('resources', 'fashion', 'helloworld.html'))), 'r') as fp, \
             open(html_path, 'w') as fw:
         t = fp.read()
         t = t.replace('{% RESULT %}', '\n'.join(result_html))
         t = t.replace('{% PRECISION_EVALUATION %}',
-                      '{:.2f}%'.format(evaluation_value['Precision@N'] * 100.0))
+                      '{:.2f}%'.format(evaluation_value['PrecisionEvaluator'] * 100.0))
         t = t.replace('{% RECALL_EVALUATION %}',
-                      '{:.2f}%'.format(evaluation_value['Recall@N'] * 100.0))
+                      '{:.2f}%'.format(evaluation_value['RecallEvaluator'] * 100.0))
         t = t.replace('{% TOP_K %}', str(top_k))
 
         fw.write(t)
@@ -112,16 +137,24 @@ def write_html(html_path):
 
     colored_url = colored('https://opensource.jina.ai', color='cyan', attrs='underline')
     default_logger.success(
-        f'🤩 Intrigued? Play with "jina hello-world --help" and learn more about Jina at {colored_url}')
+        f'🤩 Intrigued? Play with "jina hello fashion --help" and learn more about Jina at {colored_url}')
 
 
-def download_data(targets, download_proxy=None):
+def download_data(targets, download_proxy=None, task_name='download fashion-mnist'):
+    """
+    Download data.
+
+    :param targets: target path for data.
+    :param download_proxy: download proxy (e.g. 'http', 'https')
+    :param task_name: name of the task
+    """
     opener = urllib.request.build_opener()
+    opener.addheaders = [('User-agent', 'Mozilla/5.0')]
     if download_proxy:
         proxy = urllib.request.ProxyHandler({'http': download_proxy, 'https': download_proxy})
         opener.add_handler(proxy)
     urllib.request.install_opener(opener)
-    with ProgressBar(task_name='download fashion-mnist', batch_unit='') as t:
+    with ProgressBar(task_name=task_name, batch_unit='') as t:
         for k, v in targets.items():
             if not os.path.exists(v['filename']):
                 urllib.request.urlretrieve(v['url'], v['filename'], reporthook=lambda *x: t.update_tick(.01))
@@ -132,10 +165,23 @@ def download_data(targets, download_proxy=None):
 
 
 def load_mnist(path):
+    """
+    Load MNIST data
+
+    :param path: path of data
+    :return: MNIST data in np.array
+    """
+
     with gzip.open(path, 'rb') as fp:
         return np.frombuffer(fp.read(), dtype=np.uint8, offset=16).reshape([-1, 784])
 
 
 def load_labels(path: str):
+    """
+    Load labels from path
+
+    :param path: path of labels
+    :return: labels in np.array
+    """
     with gzip.open(path, 'rb') as fp:
         return np.frombuffer(fp.read(), dtype=np.uint8, offset=8).reshape([-1, 1])
