@@ -47,6 +47,12 @@ def deprecated_alias(**aliases):
     """
 
     def rename_kwargs(func_name: str, kwargs, aliases):
+        """
+        Raise warnings or exceptions for deprecated arguments.
+
+        :param func_name: Name of the function.
+        :param aliases: kwargs with key as the deprecated arg name and value be a tuple, (new_name, deprecate_level).
+        """
         for alias, new_arg in aliases.items():
             if not isinstance(new_arg, tuple):
                 raise ValueError(f'{new_arg} must be a tuple, with first element as the new name, '
@@ -66,8 +72,11 @@ def deprecated_alias(**aliases):
                     raise NotSupportedError(f'{alias} has been renamed to `{new_name}`')
 
     def deco(f):
+        """Set Decorator function."""
+
         @functools.wraps(f)
         def wrapper(*args, **kwargs):
+            """Set wrapper function."""
             rename_kwargs(f.__name__, kwargs, aliases)
             return f(*args, **kwargs)
 
@@ -182,6 +191,10 @@ def parse_arg(v: str) -> Optional[Union[bool, int, str, list, float]]:
     :param v: The string of arguments
     :return: The parsed arguments list.
     """
+    m = re.match(r'^[\'"](.*)[\'"]$', v)
+    if m:
+        return m.group(1)
+
     if v.startswith('[') and v.endswith(']'):
         # function args must be immutable tuples not list
         tmp = v.replace('[', '').replace(']', '').strip().split(',')
@@ -421,6 +434,11 @@ _RESET = '\033[0m'
 
 
 def build_url_regex_pattern():
+    """
+    Set up the regex pattern of URL.
+
+    :return: Regex pattern.
+    """
     ul = '\u00a1-\uffff'  # Unicode letters range (must not be a raw string).
 
     # IP patterns
@@ -742,21 +760,6 @@ def typename(obj):
         return str(obj)
 
 
-def rsetattr(obj, attr: str, val):
-    pre, _, post = attr.rpartition('.')
-    return setattr(rgetattr(obj, pre) if pre else obj, post, val)
-
-
-def rgetattr(obj, attr: str, *args):
-    def _getattr(obj, attr):
-        if isinstance(obj, dict):
-            return obj.get(attr, None)
-        else:
-            return getattr(obj, attr, *args)
-
-    return functools.reduce(_getattr, [obj] + attr.split('.'))
-
-
 class cached_property:
     """The decorator to cache property of a class."""
 
@@ -881,6 +884,8 @@ def is_jupyter() -> bool:  # pragma: no cover
     shell = get_ipython().__class__.__name__  # noqa: F821
     if shell == 'ZMQInteractiveShell':
         return True  # Jupyter notebook or qtconsole
+    elif shell == 'Shell':
+        return True  # Google colab
     elif shell == 'TerminalInteractiveShell':
         return False  # Terminal running IPython
     else:
@@ -903,8 +908,11 @@ def run_async(func, *args, **kwargs):
     :return: asyncio.run(func)
     """
 
-    class RunThread(threading.Thread):
+    class _RunThread(threading.Thread):
+        """Create a running thread when in Jupyter notebook."""
+
         def run(self):
+            """Run given `func` asynchronously."""
             self.result = asyncio.run(func(*args, **kwargs))
 
     try:
@@ -916,7 +924,7 @@ def run_async(func, *args, **kwargs):
         # eventloop already exist
         # running inside Jupyter
         if is_jupyter():
-            thread = RunThread()
+            thread = _RunThread()
             thread.start()
             thread.join()
             try:
