@@ -1,18 +1,21 @@
 from typing import Dict, Any, Type
 
 from ..base import VersionedYAMLParser
+from ....enums import PodRoleType
 from ....flow.base import BaseFlow
-from ....helper import expand_env_var
+from ....helper import expand_env_var, ArgNamespace
+from ....parsers import set_gateway_parser, set_pod_parser
 
 
 class LegacyParser(VersionedYAMLParser):
+    """The legacy parser."""
     version = 'legacy'  # the version number this parser designed for
 
     def parse(self, cls: Type['BaseFlow'], data: Dict) -> 'BaseFlow':
-        """Return the Flow YAML parser given the syntax version number
-
+        """
         :param cls: target class type to parse into, must be a :class:`JAMLCompatible` type
         :param data: flow yaml file loaded as python dict
+        :return: the Flow YAML parser given the syntax version number
         """
         p = data.get('with', {})  # type: Dict[str, Any]
         a = p.pop('args') if 'args' in p else ()
@@ -32,9 +35,9 @@ class LegacyParser(VersionedYAMLParser):
         return obj
 
     def dump(self, data: 'BaseFlow') -> Dict:
-        """Return the dictionary given a versioned flow object
-
+        """
         :param data: versioned flow object
+        :return: the dictionary given a versioned flow object
         """
         r = {}
         if data._version:
@@ -55,7 +58,14 @@ class LegacyParser(VersionedYAMLParser):
                 continue
 
             kwargs = {'needs': list(v.needs)} if v.needs else {}
-            kwargs.update(v._kwargs)
+
+            parser = set_pod_parser()
+            if v.role == PodRoleType.GATEWAY:
+                parser = set_gateway_parser()
+
+            non_default_kw = ArgNamespace.get_non_defaults_args(v.args, parser)
+
+            kwargs.update(non_default_kw)
 
             if 'name' in kwargs:
                 kwargs.pop('name')
