@@ -17,11 +17,14 @@ from ..jaml import JAML
 
 
 class NTLogger:
-    def __init__(self, context: str, log_level: 'LogVerbosity' = LogVerbosity.INFO):
-        """A compatible logger for Windows system, colors are all removed to keep compat.
+    """A compatible logger for Windows system, colors are all removed to keep compatible."""
 
-        :param context: the name prefix of each log
-        :param verbose: show debug level info
+    def __init__(self, context: str, log_level: 'LogVerbosity' = LogVerbosity.INFO):
+        """
+        Create a compatible logger for Windows system, colors are all removed to keep compatible.
+
+        :param context: The name prefix of each log.
+        :param log_level: Level of log.
         """
         self.context = self._planify(context)
         self.log_level = log_level
@@ -31,51 +34,83 @@ class NTLogger:
         return re.sub(r'\u001b\[.*?[@-~]', '', msg)
 
     def info(self, msg: str, **kwargs):
-        """log info-level message"""
+        """
+        Log info-level message.
+
+        :param kwargs: Keyword arguments.
+        :param msg: Context of log.
+        """
         if self.log_level <= LogVerbosity.INFO:
             sys.stdout.write(f'{self.context}[I]:{self._planify(msg)}')
 
     def critical(self, msg: str, **kwargs):
-        """log critical-level message"""
+        """
+        Log critical-level message.
+
+        :param kwargs: Keyword arguments.
+        :param msg: Context of log.
+        """
         if self.log_level <= LogVerbosity.CRITICAL:
             sys.stdout.write(f'{self.context}[C]:{self._planify(msg)}')
 
     def debug(self, msg: str, **kwargs):
-        """log debug-level message"""
+        """
+        Log debug-level message.
+
+        :param kwargs: Keyword arguments.
+        :param msg: Content of log.
+        """
         if self.log_level <= LogVerbosity.DEBUG:
             sys.stdout.write(f'{self.context}[D]:{self._planify(msg)}')
 
     def error(self, msg: str, **kwargs):
-        """log error-level message"""
+        """
+        Log error-level message.
+
+        :param kwargs: Keyword arguments.
+        :param msg: Context of log.
+        """
         if self.log_level <= LogVerbosity.ERROR:
             sys.stdout.write(f'{self.context}[E]:{self._planify(msg)}')
 
     def warning(self, msg: str, **kwargs):
-        """log warn-level message"""
+        """
+        Log warning-level message.
+
+        :param kwargs: Keyword arguments.
+        :param msg: Context of log.
+        """
         if self.log_level <= LogVerbosity.WARNING:
             sys.stdout.write(f'{self.context}[W]:{self._planify(msg)}')
 
     def success(self, msg: str, **kwargs):
-        """log success-level message"""
+        """
+        Log success-level message.
+
+        :param msg: Context of log.
+        :param kwargs: Keyword arguments.
+        """
         if self.log_level <= LogVerbosity.SUCCESS:
             sys.stdout.write(f'{self.context}[S]:{self._planify(msg)}')
 
 
 class PrintLogger(NTLogger):
-
+    """Print the message."""
     @staticmethod
     def _planify(msg):
         return msg
 
 
 class SysLogHandlerWrapper(logging.handlers.SysLogHandler):
-    """ Override the priority_map :class:`SysLogHandler`
+    """
+    Override the priority_map :class:`SysLogHandler`.
 
     .. warning::
         This messages at DEBUG and INFO are therefore not stored by ASL, (ASL = Apple System Log)
         which in turn means they can't be printed by syslog after the fact. You can confirm it via :command:`syslog` or
-        :command:`tail -f /var/log/system.log`
+        :command:`tail -f /var/log/system.log`.
     """
+
     priority_map = {
         'DEBUG': 'debug',
         'INFO': 'info',
@@ -87,29 +122,40 @@ class SysLogHandlerWrapper(logging.handlers.SysLogHandler):
 
 
 class JinaLogger:
+    """
+    Build a logger for a context.
+
+    :param context: The context identifier of the class, module or method.
+    :param log_config: The configuration file for the logger.
+    :param identity: The id of the group the messages from this logger will belong, used by fluentd default
+    configuration to group logs by pod.
+    :param workspace_path: The workspace path where the log will be stored at (only apply to fluentd)
+    :returns: an executor object.
+    """
     supported = {'FileHandler', 'StreamHandler', 'SysLogHandler', 'FluentHandler'}
 
     def __init__(self,
                  context: str,
                  name: Optional[str] = None,
                  log_config: Optional[str] = None,
-                 log_id: Optional[str] = None, **kwargs):
-        """Build a logger for a context
-        :param context: The context identifier of the class, module or method
-        :param log_config: the configuration file for the logger
-        :param log_id: the id of the group the messages from this logger will belong, used by fluentd default configuration
-        to group logs by pod
-        :return: an executor object
-        """
+                 identity: Optional[str] = None,
+                 workspace_path: Optional[str] = None,
+                 quiet: bool = False,
+                 **kwargs):
         from .. import __uptime__
-        if log_config is None:
+        if not log_config:
             log_config = os.getenv('JINA_LOG_CONFIG',
                                    resource_filename('jina', '/'.join(
                                        ('resources', 'logging.default.yml'))))
-        if log_id is None:
-            log_id = os.getenv('JINA_LOG_ID', None)
 
-        if name is None:
+        if quiet or os.getenv('JINA_LOG_CONFIG', None) == 'QUIET':
+            log_config = resource_filename('jina', '/'.join(
+                ('resources', 'logging.quiet.yml')))
+
+        if not identity:
+            identity = os.getenv('JINA_LOG_ID', None)
+
+        if not name:
             name = os.getenv('JINA_POD_NAME', context)
 
         # Remove all handlers associated with the root logger object.
@@ -119,11 +165,16 @@ class JinaLogger:
         self.logger = logging.getLogger(context)
         self.logger.propagate = False
 
+        if workspace_path is None:
+            workspace_path = os.getenv('JINA_LOG_WORKSPACE', '/tmp/jina/')
+
         context_vars = {'name': name,
                         'uptime': __uptime__,
-                        'context': context}
-        if log_id:
-            context_vars['log_id'] = log_id
+                        'context': context,
+                        'workspace_path': workspace_path}
+        if identity:
+            context_vars['log_id'] = identity
+
         self.add_handlers(log_config, **context_vars)
 
         # note logger.success isn't default there
@@ -140,6 +191,11 @@ class JinaLogger:
 
     @property
     def handlers(self):
+        """
+        Get the handlers of the logger.
+
+        :returns: Handlers of logger.
+        """
         return self.logger.handlers
 
     def __enter__(self):
@@ -149,10 +205,17 @@ class JinaLogger:
         self.close()
 
     def close(self):
+        """Close all the handlers."""
         for handler in self.logger.handlers:
             handler.close()
 
     def add_handlers(self, config_path: str = None, **kwargs):
+        """
+        Add handlers from config file.
+
+        :param config_path: Path of config file.
+        :param kwargs: Extra parameters.
+        """
         self.logger.handlers = []
 
         with open(config_path) as fp:
@@ -208,4 +271,6 @@ class JinaLogger:
                 self.logger.addHandler(handler)
 
         verbose_level = LogVerbosity.from_string(config['level'])
+        if 'JINA_LOG_LEVEL' in os.environ:
+            verbose_level = LogVerbosity.from_string(os.environ['JINA_LOG_LEVEL'])
         self.logger.setLevel(verbose_level.value)
