@@ -1,43 +1,84 @@
+"""Module for helper functions in the parser"""
 import argparse
 import os
+import uuid
+from typing import Tuple
 
 _SHOW_ALL_ARGS = 'JINA_FULL_CLI' in os.environ
+if _SHOW_ALL_ARGS:
+    from jina.logging import default_logger
+    default_logger.warning(f'Setting {_SHOW_ALL_ARGS} will make remote Peas with sharding not work when using JinaD')
 
 
 def add_arg_group(parser, title):
+    """Add the arguments for a specific group to the parser
+
+    :param parser: the parser configure
+    :param title: the group name
+    :return: the new parser
+    """
     return parser.add_argument_group(f'{title} arguments')
 
 
-class KVAppendAction(argparse.Action):
+def UUIDString(astring) -> str:
+    """argparse type to check if a string is a valid UUID string
+
+    :param astring: the string to check
+    :return: the string
     """
-    argparse action to split an argument into KEY=VALUE form
+    uuid.UUID(astring)
+    return astring
+
+
+class KVAppendAction(argparse.Action):
+    """argparse action to split an argument into KEY=VALUE form
     on the first = and append to a dictionary.
     This is used for setting up --env
     """
 
     def __call__(self, parser, args, values, option_string=None):
-        import json
+        """
+        call the KVAppendAction
+
+
+        .. # noqa: DAR401
+        :param parser: the parser
+        :param args: args to initialize the values
+        :param values: the values to add to the parser
+        :param option_string: inherited, not used
+        """
+        import json, re
+        from ..helper import parse_arg
         d = getattr(args, self.dest) or {}
         for value in values:
             try:
                 d.update(json.loads(value))
             except json.JSONDecodeError:
                 try:
-                    (k, v) = value.split('=', 2)
+                    k, v = re.split(r'[:=]\s*', value, maxsplit=1)
                 except ValueError:
                     raise argparse.ArgumentTypeError(f'could not parse argument \"{values[0]}\" as k=v format')
-                d[k] = v
+                d[k] = parse_arg(v)
         setattr(args, self.dest, d)
 
 
 class DockerKwargsAppendAction(argparse.Action):
-    """
-    argparse action to split an argument into KEY: VALUE form
+    """argparse action to split an argument into KEY: VALUE form
     on the first : and append to a dictionary.
     This is used for setting up arbitrary kwargs for docker sdk
     """
 
     def __call__(self, parser, args, values, option_string=None):
+        """
+        call the DockerKwargsAppendAction
+
+
+        .. # noqa: DAR401
+        :param parser: the parser
+        :param args: args to initialize the values
+        :param values: the values to add to the parser
+        :param option_string: inherited, not used
+        """
         import json
         d = getattr(args, self.dest) or {}
 
@@ -73,7 +114,7 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
                 self.formatter._dedent()
 
             # return nothing if the section was empty
-            if not item_help:
+            if not item_help.strip():
                 return ''
 
             # add the heading if the section was non-empty
@@ -96,22 +137,33 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         self._current_section = section
 
     def _get_help_string(self, action):
-        help_string = action.help
+        help_string = ''
         if '%(default)' not in action.help:
             if action.default is not argparse.SUPPRESS:
                 from ..helper import colored
                 defaulting_nargs = [argparse.OPTIONAL, argparse.ZERO_OR_MORE]
                 if isinstance(action, argparse._StoreTrueAction):
 
-                    help_string += colored(' (default: %s)' % (
+                    help_string = colored('default: %s' % (
                         'enabled' if action.default else f'disabled, use "--{action.dest}" to enable it'),
-                                    attrs=['dark'])
+                                          attrs=['dark'])
                 elif action.choices:
                     choices_str = f'{{{", ".join([str(c) for c in action.choices])}}}'
-                    help_string += colored(' (choose from: ' + choices_str + '; default: %(default)s)', attrs=['dark'])
+                    help_string = colored('choose from: ' + choices_str + '; default: %(default)s', attrs=['dark'])
                 elif action.option_strings or action.nargs in defaulting_nargs:
-                    help_string += colored(' (type: %(type)s; default: %(default)s)', attrs=['dark'])
-        return help_string
+                    help_string = colored('type: %(type)s; default: %(default)s', attrs=['dark'])
+        return f'''
+        
+        {help_string}
+        
+        {action.help}
+        
+        '''
+
+    def _join_parts(self, part_strings):
+        return '\n' + ''.join([part
+                               for part in part_strings
+                               if part and part is not argparse.SUPPRESS])
 
     def _get_default_metavar_for_optional(self, action):
         return ''
@@ -151,8 +203,85 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
 
         return formatter
 
+    def _split_lines(self, text, width):
+        return self._para_reformat(text, width)
+
     def _fill_text(self, text, width, indent):
-        return ''.join(indent + line for line in text.splitlines(keepends=True))
+        lines = self._para_reformat(text, width)
+        return '\n'.join(lines)
+
+    def _indents(self, line) -> Tuple[int, int]:
+        """Return line indent level and "sub_indent" for bullet list text.
+
+        :param line: the line to check
+        :return: indentation of line and indentation of sub-items
+        """
+        import re
+        indent = len(re.match(r'( *)', line).group(1))
+        list_match = re.match(r'( *)(([*\-+>]+|\w+\)|\w+\.) +)', line)
+        if list_match:
+            sub_indent = indent + len(list_match.group(2))
+        else:
+            sub_indent = indent
+
+        return (indent, sub_indent)
+
+    def _split_paragraphs(self, text):
+        """Split text into paragraphs of like-indented lines.
+
+        :param text: the text input
+        :return: list of paragraphs
+        """
+
+        import textwrap, re
+
+        text = textwrap.dedent(text).strip()
+        text = re.sub('\n\n[\n]+', '\n\n', text)
+
+        last_sub_indent = None
+        paragraphs = list()
+        for line in text.splitlines():
+            (indent, sub_indent) = self._indents(line)
+            is_text = len(line.strip()) > 0
+
+            if is_text and indent == sub_indent == last_sub_indent:
+                paragraphs[-1] += ' ' + line
+            else:
+                paragraphs.append(line)
+
+            if is_text:
+                last_sub_indent = sub_indent
+            else:
+                last_sub_indent = None
+
+        return paragraphs
+
+    def _para_reformat(self, text, width):
+        """Format text, by paragraph.
+
+        :param text: the text to format
+        :param width: the width to apply
+        :return: the new text
+        """
+
+        import textwrap
+
+        lines = list()
+        for paragraph in self._split_paragraphs(text):
+            (indent, sub_indent) = self._indents(paragraph)
+
+            paragraph = self._whitespace_matcher.sub(' ', paragraph).strip()
+            new_lines = textwrap.wrap(
+                text=paragraph,
+                width=width,
+                initial_indent=' ' * indent,
+                subsequent_indent=' ' * sub_indent,
+            )
+
+            # Blank lines get eaten by textwrap, put it back
+            lines.extend(new_lines or [''])
+
+        return lines
 
 
 _chf = _ColoredHelpFormatter
