@@ -1,3 +1,4 @@
+"""Argparser module for ZED runtime"""
 import argparse
 
 from ...helper import add_arg_group, _SHOW_ALL_ARGS
@@ -7,14 +8,16 @@ from ....helper import random_port
 
 
 def mixin_zed_runtime_parser(parser):
-    """Mixing in arguments required by :class:`ZEDRuntime` into the given parser."""
+    """Mixing in arguments required by :class:`ZEDRuntime` into the given parser.
+    :param parser: the parser instance to which we add arguments
+    """
 
     gp = add_arg_group(parser, title='ZEDRuntime')
 
     gp.add_argument('--uses', type=str, default='_pass',
                     help='''
 The config of the executor, it could be one of the followings: 
-- an Executor-level YAML file path (*.yml/yaml) 
+- an Executor-level YAML file path (.yml, .yaml, .jaml) 
 - a name of a class inherited from `jina.Executor`
 - a docker image (must start with `docker://`)
 - builtin executors, e.g. `_pass`, `_logforward`, `_merge` 
@@ -80,4 +83,3 @@ is wrong in the upstream, it is hard to carry this exception and moving forward
     gp.add_argument('--num-part', type=int, default=0,
                     help='the number of messages expected from upstream, 0 and 1 means single part'
                     if _SHOW_ALL_ARGS else argparse.SUPPRESS)
-
