@@ -105,7 +105,7 @@ class BaseRuntime:
 
             This method will only be called if the :meth:`setup` succeeds.
         """
-        pass
+        self.logger.close()
 
     def __init__(self, args: 'argparse.Namespace'):
         super().__init__()
@@ -114,6 +114,4 @@ class BaseRuntime:
             self.name = f'{args.name}/{self.__class__.__name__}'
         else:
             self.name = self.__class__.__name__
-        self.logger = JinaLogger(self.name,
-                                 log_id=self.args.log_id,
-                                 log_config=self.args.log_config)
+        self.logger = JinaLogger(self.name, **vars(self.args))
