@@ -6,18 +6,19 @@ from .client import PeaDaemonClient
 from ..asyncio.base import AsyncZMQRuntime
 from ...zmq import Zmqlet
 from ....excepts import DaemonConnectivityError
-from ....helper import cached_property, colored
+from ....helper import cached_property, colored, is_yaml_filepath
 
 
 class JinadRuntime(AsyncZMQRuntime):
-
+    """Runtime procedure for Jinad."""
     def __init__(self, args: 'argparse.Namespace'):
         super().__init__(args)
         self.ctrl_addr = Zmqlet.get_ctrl_address(None, None, True)[0]
         self.timeout_ctrl = args.timeout_ctrl
         self.host = args.host
         self.port_expose = args.port_expose
-        self.api = PeaDaemonClient(host=self.host, port=self.port_expose, logger=self.logger)
+        self.api = PeaDaemonClient(host=self.host, port=self.port_expose, logger=self.logger,
+                                   timeout=self.args.timeout_ready)
 
     def setup(self):
         """
@@ -54,18 +55,23 @@ class JinadRuntime(AsyncZMQRuntime):
         Closes the remote Pod/Pea using :class:`JinadAPI`
         """
         self.api.delete(remote_id=self._remote_id)
+        super().teardown()
 
     @cached_property
     def _remote_id(self) -> Optional[str]:
         if self.api.is_alive:
             upload_files = []
-            if self.args.uses.endswith('.yml') or self.args.uses.endswith('.yaml'):
+            if is_yaml_filepath(self.args.uses):
                 upload_files.append(self.args.uses)
-                if not self.args.upload_files:
-                    self.logger.warning(f'will upload {self.args.uses} to remote, to include more local file '
-                                        f'dependencies, please use `--upload-files`')
+
+            if is_yaml_filepath(self.args.uses_internal):
+                upload_files.append(self.args.uses_internal)
+
             if self.args.upload_files:
                 upload_files.extend(self.args.upload_files)
+            else:
+                self.logger.warning(f'will upload {upload_files} to remote, to include more local file '
+                                    f'dependencies, please use `--upload-files`')
 
             if upload_files:
                 workspace_id = self.api.upload(dependencies=list(set(upload_files)),
